import "date-fns";
import React from "react";
import {
  Button,
  Fab,
  Grid,
  TextField,
  FormControl,
  InputLabel,
  Select,
  MenuItem,
  Paper,
  Typography,
  Divider,
  Table,
  TableCell,
  TableHead,
  TableRow,
  TableBody,
  IconButton
} from "@material-ui/core";
import TrashIcon from "@material-ui/icons/Delete";
import AddIcon from "@material-ui/icons/Add";
import MoreHorizonIcon from "@material-ui/icons/MoreHoriz";
import ChevronLeftIcon from "@material-ui/icons/ChevronLeft";
import { makeStyles } from "@material-ui/core/styles";
import DateFnsUtils from "@date-io/date-fns";
import {
  MuiPickersUtilsProvider,
  KeyboardTimePicker,
  KeyboardDatePicker
} from "@material-ui/pickers";

const useStyles = makeStyles({
  grid: {
    width: "60%"
  },
  paper: {
    margin: 12,
    paddingBottom: 12
  },
  paperHeaderBack: {
    color: "grey",
    padding: 12
  },
  paperHeader: {
    color: "grey",
    padding: "12px"
  },
  paperHeaderActions: {},
  paperActions: {
    justify: "flex-end",
    padding: 0,
    margin: 0
  },
  paperActionItem: {
    paddingLeft: 40
  },
  item: {
    paddingLeft: "12px",
    paddingRight: "12px"
  },
  amount: {
    textAlign: "right"
  },
  formContainer: {
    display: "flex"
  },
  innerContainer: {
    spacing: 12
  },
  innerLeftItem: {
    paddingLeft: 0,
    paddingRight: 12
  },
  innerRightItem: {
    paddingLeft: 12,
    paddingRight: 0
  },
  selectItem: {
    width: "100%"
  },
  textField: {
    width: "100%"
  },
  fab: {
    position: "absolute",
    bottom: 20,
    right: 20
  }
});

function createData(a, b, c, d, e, f, g, h, i, j, k) {
  return { a, b, c, d, e, f, g, h, i, j, k };
}

const rowsServices = [
  createData("A1  General Consultation", "1.00", "400.00"),
  createData("I113  BLOOD SUGAR-RANDOM OR FASTING", "1.00", "1250.00")
];

const rowsItems = [
  createData("0182  PARACETAMOL TABS 500 MG", "2.00", "10.00")
];

export default function MaterialUIPickers() {
  const classes = useStyles();

  return (
    <MuiPickersUtilsProvider utils={DateFnsUtils}>
      <form className={classes.formContainer} noValidate autoComplete="off">
        <Grid container>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={1} className={classes.paperHeaderBack}>
                  <IconButton>
                    <ChevronLeftIcon />
                  </IconButton>
                </Grid>
                <Grid container xs={11} alignItems="center">
                  <Grid item xs={12} className={classes.paperHeader}>
                    <Typography variant="h6">Claim Details</Typography>
                  </Grid>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Health Facility"
                    className={classes.textField}
                    value="VIHC001 - Juilöa Health Centre"
                    margin="normal"
                  />
                </Grid>
                <Grid item xs={3} className={classes.item} />
                <Grid item xs={3} className={classes.item}>
                  <KeyboardDatePicker
                    margin="normal"
                    id="mui-pickers-date"
                    label="Visit Date From"
                    fullWidth={true}
                    KeyboardButtonProps={{
                      "aria-label": "change date"
                    }}
                  />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <KeyboardDatePicker
                    margin="normal"
                    id="mui-pickers-date"
                    label="Visit Date To"
                    fullWidth={true}
                    KeyboardButtonProps={{
                      "aria-label": "change date"
                    }}
                  />
                </Grid>

                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Patient"
                    className={classes.textField}
                    value="Doni Ilina"
                    margin="normal"
                  />
                </Grid>

                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Insurance"
                    className={classes.textField}
                    value="105000002"
                    margin="normal"
                  />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Guarantee"
                    className={classes.textField}
                    value=""
                    margin="normal"
                  />
                </Grid>
                <Grid item xs={3} className={classes.item} />

                <Grid item xs={6} className={classes.item}>
                  <Grid container className={classes.innerContainer}>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Main Dg."
                        className={classes.textField}
                        value="A000 Cholera due to Vibrio cholerae 01, biovar cholerae"
                        margin="normal"
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="visit-type-name"
                        label="Visit Type"
                        className={classes.textField}
                        value="Emergency"
                        margin="normal"
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg1"
                        className={classes.textField}
                        value="A001 Cholera due to Vibrio cholerae 01, biovar eltor"
                        margin="normal"
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg2"
                        className={classes.textField}
                        value=""
                        margin="normal"
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg3"
                        className={classes.textField}
                        value=""
                        margin="normal"
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg4"
                        className={classes.textField}
                        value=""
                        margin="normal"
                      />
                    </Grid>
                  </Grid>
                </Grid>
                <Grid item xs={6} className={classes.item}>
                  <Grid container className={classes.innerContainer}>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Claim No."
                        className={classes.textField}
                        value="CIB00001"
                        margin="normal"
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Claimed"
                        className={classes.textField}
                        value="5250"
                        margin="normal"
                        inputProps={{
                          className: classes.amount
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <KeyboardDatePicker
                        margin="normal"
                        id="mui-pickers-date"
                        label="Date Claimed"
                        fullWidth={true}
                        KeyboardButtonProps={{
                          "aria-label": "change date"
                        }}
                        color="grey"
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Adjusted"
                        className={classes.textField}
                        value="250"
                        margin="normal"
                        inputProps={{
                          className: classes.amount
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Claim Administrator"
                        className={classes.textField}
                        value="UHOS0011	"
                        margin="normal"
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Approved"
                        className={classes.textField}
                        value="5000"
                        margin="normal"
                        inputProps={{
                          className: classes.amount
                        }}
                      />
                    </Grid>
                  </Grid>
                </Grid>
              </Grid>
            </Paper>
          </Grid>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={11} className={classes.paperHeader}>
                  <Typography variant="h6">Services (2)</Typography>
                </Grid>
                <Grid item xs={1} className={classes.paperHeader}>
                  <Grid
                    container
                    className={classes.paperHeaderActions}
                    justify="flex-end"
                    alignItems="flex-end"
                    alignContent="flex-end"
                  >
                    <Grid item xs={12} className={classes.paperActionItem}>
                      <IconButton>
                        <AddIcon />
                      </IconButton>
                    </Grid>
                  </Grid>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
                <Grid item xs={12}>
                  <Table className={classes.table} size="small">
                    <TableHead>
                      <TableRow>
                        <TableCell align="center">Code</TableCell>
                        <TableCell align="center">Quantity</TableCell>
                        <TableCell align="center">Price</TableCell>
                        <TableCell align="center">Explanation</TableCell>
                        <TableCell align="center" />
                      </TableRow>
                    </TableHead>
                    <TableBody>
                      {rowsServices.map(row => (
                        <TableRow key={row.name}>
                          <TableCell component="th" scope="row" align="left">
                            <Grid container>
                              <Grid item xs={11}>
                                {row.a}
                              </Grid>
                              <Grid item xs={1}>
                                <IconButton align="right">
                                  <MoreHorizonIcon />
                                </IconButton>
                              </Grid>
                            </Grid>
                          </TableCell>
                          <TableCell align="right">{row.b}</TableCell>
                          <TableCell align="right">{row.c}</TableCell>
                          <TableCell align="left">{row.d}</TableCell>
                          <TableCell align="right">
                            <IconButton>
                              <TrashIcon />
                            </IconButton>
                          </TableCell>
                        </TableRow>
                      ))}
                    </TableBody>
                  </Table>
                </Grid>
              </Grid>
            </Paper>
          </Grid>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={11} className={classes.paperHeader}>
                  <Typography variant="h6">Items (1)</Typography>
                </Grid>
                <Grid item xs={1} className={classes.paperHeader}>
                  <Grid container justify="flex-end">
                    <Grid item xs={12} className={classes.paperActionItem}>
                      <IconButton>
                        <AddIcon />
                      </IconButton>
                    </Grid>
                  </Grid>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
              </Grid>
              <Grid item xs={12}>
                <Table className={classes.table} size="small">
                  <TableHead>
                    <TableRow>
                      <TableCell align="center">Code</TableCell>
                      <TableCell align="center">Quantity</TableCell>
                      <TableCell align="center">Price</TableCell>
                      <TableCell align="center">Explanation</TableCell>
                      <TableCell align="center" />
                    </TableRow>
                  </TableHead>
                  <TableBody>
                    {rowsItems.map(row => (
                      <TableRow key={row.name}>
                        <TableCell component="th" scope="row" align="left">
                          <Grid container>
                            <Grid item xs={11}>
                              {row.a}
                            </Grid>
                            <Grid item xs={1}>
                              <IconButton align="right">
                                <MoreHorizonIcon />
                              </IconButton>
                            </Grid>
                          </Grid>
                        </TableCell>
                        <TableCell align="right">{row.b}</TableCell>
                        <TableCell align="right">{row.c}</TableCell>
                        <TableCell align="left">{row.d}</TableCell>
                        <TableCell align="right">
                          <IconButton>
                            <TrashIcon />
                          </IconButton>
                        </TableCell>
                      </TableRow>
                    ))}
                  </TableBody>
                </Table>
              </Grid>
            </Paper>
          </Grid>
          <Grid container>
            <Grid item xs={12}>
              <Paper className={classes.paper}>
                <Grid container>
                  <Grid item xs={12} className={classes.item}>
                    <TextField
                      id="standard-name"
                      label="Explanation"
                      className={classes.textField}
                      value=""
                      margin="normal"
                      fullWidth={true}
                    />
                  </Grid>
                </Grid>
              </Paper>
            </Grid>
          </Grid>
        </Grid>
      </form>
      <Fab color="primary" aria-label="Add" className={classes.fab}>
        <AddIcon />
      </Fab>
    </MuiPickersUtilsProvider>
  );
}
